
import java.util.Vector;

/**
 * Entre 2 Almas	[https://sourceforge.net/projects/entre2almas/]  
 * ------------------------------------------------------------------------
 * This file is part of "Entre 2 Almas".
 * "Entre 2 Almas" is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * "Entre 2 Almas" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "Entre 2 Almas"; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ------------------------------------------------------------------------
 * 		Copyright 2005 - 2006 Pedro Javier Sez Martnez
 * 
 * 
 * Una conversacin se dar entre nuestro personaje y un objeto Item. Implementa
 * las interfaces Opcionable y Comparable.
 * 
 * @author Pedro Javier Sez Martnez
 * @version 1.0
 */
public class Conversacion implements Opcionable, Comparable {

	/**
	 * identificador de la conversacin
	 */
	int id;

	/**
	 * Color con el que se identificar el personaje con el que habla Oscar
	 */
	int color;

	/**
	 * Array que indica que las opciones disponibles.
	 */
	public Opcion[] opciones;

	/**
	 * Constructor de la clase Conversacin
	 * 
	 * @param id
	 *            identificador de la conversacin
	 * @param color
	 *            Color con el que se identificar el personaje con el que habla
	 *            Oscar
	 * @param opciones
	 *            indica que las opciones disponibles.
	 */
	public Conversacion(int id, int color, Vector opciones) {
		this.id = id;
		this.color = color;
		this.opciones = new Opcion[opciones.size()];
		opciones.copyInto(this.opciones);
	}

	/**
	 * Indica si una determinada accin tiene o no alguna consecuencia
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si esa opcin o accin tiene alguna
	 *         consecuencia si es true es que no hay consecuencias, y viceversa.
	 */
	public boolean getConseActivaAcc(int opcionSele) {

		return opciones[opcionSele].consecuencias.isEmpty();
	}

	/**
	 * Establece la consecuencia activa para una determinada accin.
	 * 
	 * @param id
	 *            Identificador de la opcin a modificar.
	 * @param valor
	 *            el nuevo valor de conseActiva
	 */
	public void setConseActivaAcc(String id, int valor) {
		Opcion auxOp = getOpcion(id);
		auxOp.conseActiva = valor;
	}

	/**
	 * Devuelve la consecuencia para una determinada accin
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return Vector con la consecuencia activa para una determinada accin
	 */
	public Vector getConsecuenciaAcc(int opcionSele) {

		return (Vector) opciones[opcionSele].consecuencias
				.elementAt(opciones[opcionSele].conseActiva);
	}

	/**
	 * El nombre de una determinada accin.
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return nombre de la accin.
	 */
	public String getNombreAccion(int opcionSele) {
		return opciones[opcionSele].texto;
	}

	/**
	 * Devuelve el numero de acciones disponibles para un Seleccionable
	 * 
	 * @return el numero de acciones disponibles para un Seleccionable
	 */
	public int longAcciones() {
		return opciones.length;
	}

	/**
	 * Establece si una accin esta activa o no
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @param valor
	 *            boolean indicando si est activa o no.
	 */
	public void setAccionActiva(int opcionSele, boolean valor) {
		opciones[opcionSele].activa = valor;
	}

	/**
	 * Indica si una determinada accin esta activa o no.
	 * 
	 * @param opcionSele
	 *            La opcin seleccionada en el juego
	 * @return boolean indicando si la opcin est o no activa.
	 */
	public boolean getAccionActiva(int opcionSele) {
		return opciones[opcionSele].activa;
	}

	/**
	 * Devuelve la clave del comparable
	 * 
	 * @return La clave del comparable identificador del comparable.
	 */
	public int getKey() {
		return id;
	}

	/**
	 * Devuelve la opcin cuyo id coincide con el que se pasa como parmetro
	 * 
	 * @param id
	 *            String con el identificador de la opcin
	 * @return La opcin cuyo id coincide con el de la opcin.
	 */
	public Opcion getOpcion(String id) {
		for (int i = 0; i < longAcciones(); i++) {
			if (opciones[i] != null) {
				if (opciones[i].id.equals(id)) {
					return opciones[i];
				}
			}
		}
		return null;
	}

	/**
	 * Borra una opcin de entra las disponibles
	 * 
	 * @param id
	 *            Identificador de la opcin.
	 */
	public void borrarOp(String id) {
		for (int i = 0; i < longAcciones(); i++)
			if (opciones[i] != null)
				if (opciones[i].id.equals(id))
					opciones[i] = null;
	}

}
